function[]=sections_MODEL(varargin)
% function[]=sections_MODEL()
% standalone function that creates sections and areas from any model grid
% files.
% JD PAGO WHOI --- last modified on May, 15th, 2012

model=input('input the model (GFDL, CCSM, IPSL or CNRM): ','s');

switch model
    case 'RCHB'
    	gridfile=input('enter full path to nc file that contains some gridded observations: ','s');
    case {'GFDL','CCSM','IPSL','CNRM','NEMO'}
	disp('enter full path to nc file that contains all information')
	gridfile=input('about the model grid (scale factors, bathymetry, mask...): ','s');
    otherwise 
        error('JD PAGO error: sections_MODEL undefined for this model');
end


%% load location of center of grid cells, bathymetry and masks
switch model
    case 'GFDL'
        lont=readnc(gridfile,'geolon_t');
        latt=readnc(gridfile,'geolat_t');
        bathy=readnc(gridfile,'ht');
        mask=readnc(gridfile,'wet');
        mask(find(isnan(mask)))=0;
    case 'CCSM'
        lont=readnc(gridfile,'TLONG');
        latt=readnc(gridfile,'TLAT');
        bathy=readnc(gridfile,'HT')*1e-2;  % originally in centimeters >> convert to meters
        mask=readnc(gridfile,'REGION_MASK');
        lont(:,1:36)=lont(:,1:36)-360; % because of discontinuity in longitude
    case 'IPSL'
        lont=readnc(gridfile,'glamt');
        lont(:,53:end)=lont(:,53:end)+360; % because of discontinuity in longitude
        latt=readnc(gridfile,'gphit');
        zt=readnc(gridfile,'gdept');
        bathy_temp=readnc(gridfile,'mbathy'); bathy_temp(find(bathy_temp<0))=0;
        bathy=reshape(zt(bathy_temp(:)+1),size(bathy_temp));
        mask_temp=readnc(gridfile,'tmask');
        mask=squeeze(mask_temp(1,:,:));
    case 'CNRM'
        lont=readnc(gridfile,'glamt');
        lont(:,53:end)=lont(:,53:end)+360; % because of discontinuity in longitude
        latt=readnc(gridfile,'gphit');
        zt=readnc(gridfile,'gdept_0');
        bathy_temp=readnc(gridfile,'mbathy'); bathy_temp(find(bathy_temp<0))=0; bathy_temp(find(isnan(bathy_temp)))=0;
        bathy=reshape(zt(bathy_temp(:)+1),size(bathy_temp));
        mask_temp=readnc(gridfile,'tmask'); mask_temp(find(isnan(mask_temp)))=0;
        mask=squeeze(mask_temp(1,:,:));
    case 'RCHB'
	[lont,latt,zt,bathy,mask,dxt,dyt,dzt]=grid_HYDROBASE(gridfile);
    case 'NEMO'
        lont=readnc(gridfile,'glamt');
        lont(:,53:end)=lont(:,53:end)+360; % because of discontinuity in longitude
        latt=readnc(gridfile,'gphit');
        zt=readnc(gridfile,'gdept_0');
        bathy_temp=readnc(gridfile,'mbathy'); bathy_temp(find(bathy_temp<0))=0;
        bathy=reshape(zt(bathy_temp(:)+1),size(bathy_temp));
        mask_temp=readnc(gridfile,'tmask');
        mask=squeeze(mask_temp(1,:,:));
end
[nj,ni]=size(mask);

%% select geographical area of interest to load from netcdf files
% cyclic boundary conditions are taken into account
figure(10); clf; hold on
contour(mask,[1 1],'k')
hold on
xlabel('grid points')
ylabel('grid points')

ans_atl=input('use predefined grid in the North Atlantic? (0 or 1) ');
if ans_atl
    run grid_corrections_NA
    disp('selected area indicated in blue: (numbers are grid indices)')
    disp(['lonw=' num2str(MODEL_grid.lonw) ', lone=' num2str(MODEL_grid.lone) ', lats=' num2str(MODEL_grid.lats) ', latn=' num2str(MODEL_grid.latn)]);
else
    if input(['use predefined grid file? (0 or 1) '])
        gridname=input(['enter name of grid file with full path ... '],'s');
        while ~exist(gridname)
            gridname=input(['error in name --- please re-enter ... '],'s');
        end
        eval(['load ' gridname])
	disp('selected area indicated in blue: (numbers are grid indices)')
        disp(['lonw=' num2str(MODEL_grid.lonw) ', lone=' num2str(MODEL_grid.lone) ', lats=' num2str(MODEL_grid.lats) ', latn=' num2str(MODEL_grid.latn)]);
    else
	disp(['enter grid points defining area (1<={lonw,lone}<=' num2str(size(mask,2)) ', but 1<{lats,latn}<' num2str(size(mask,1)) ')'])
        MODEL_grid.lonw=input('lonw= ');
        MODEL_grid.lone=input('lone= ');
        MODEL_grid.lats=input('lats= ');
        MODEL_grid.latn=input('latn= ');
	disp('selected area indicated in blue.')
    end
end

figure(10)
plot([MODEL_grid.lonw MODEL_grid.lonw],[MODEL_grid.lats MODEL_grid.latn],'b')
plot([MODEL_grid.lone MODEL_grid.lone],[MODEL_grid.lats MODEL_grid.latn],'b')
if MODEL_grid.lone<MODEL_grid.lonw
    plot([MODEL_grid.lonw ni],[MODEL_grid.lats MODEL_grid.lats],'b')
    plot([MODEL_grid.lonw ni],[MODEL_grid.latn MODEL_grid.latn],'b')
    plot([0 MODEL_grid.lone],[MODEL_grid.latn MODEL_grid.latn],'b')
    plot([0 MODEL_grid.lone],[MODEL_grid.lats MODEL_grid.lats],'b')
else
    plot([MODEL_grid.lonw MODEL_grid.lone],[MODEL_grid.lats MODEL_grid.lats],'b')
    plot([MODEL_grid.lonw MODEL_grid.lone],[MODEL_grid.latn MODEL_grid.latn],'b')
end    
        
while ~input('ok with selected area? (0 or 1) ')
    disp(['enter grid points defining new area (1<={lonw,lone}<=' num2str(size(mask,2)) ', but 1<{lats,latn}<' num2str(size(mask,1)) ')'])
    MODEL_grid.lonw=input('lonw= ');
    MODEL_grid.lone=input('lone= ');
    MODEL_grid.lats=input('lats= ');
    MODEL_grid.latn=input('latn= ');
    while MODEL_grid.latn<MODEL_grid.lats
        disp('latn must be larger than lats');
        MODEL_grid.lats=input('lats= ');
        MODEL_grid.latn=input('latn= ');
    end    
    if exist('pl1')
        set(pl1,'visible','off'); set(pl2,'visible','off'); set(pl3,'visible','off'); set(pl4,'visible','off');
    end
    if exist('pl5')
        set(pl5,'visible','off'); set(pl6,'visible','off')
    end
    figure(10)
    pl1=plot([MODEL_grid.lonw MODEL_grid.lonw],[MODEL_grid.lats MODEL_grid.latn],'r');
    pl2=plot([MODEL_grid.lone MODEL_grid.lone],[MODEL_grid.lats MODEL_grid.latn],'r');
    if MODEL_grid.lone<MODEL_grid.lonw
        pl3=plot([MODEL_grid.lonw ni],[MODEL_grid.lats MODEL_grid.lats],'r');
        pl4=plot([MODEL_grid.lonw ni],[MODEL_grid.latn MODEL_grid.latn],'r');
        pl5=plot([0 MODEL_grid.lone],[MODEL_grid.latn MODEL_grid.latn],'r');
        pl6=plot([0 MODEL_grid.lone],[MODEL_grid.lats MODEL_grid.lats],'r');
    else
        pl3=plot([MODEL_grid.lonw MODEL_grid.lone],[MODEL_grid.lats MODEL_grid.lats],'r');
        pl4=plot([MODEL_grid.lonw MODEL_grid.lone],[MODEL_grid.latn MODEL_grid.latn],'r');
    end
    disp('new area indicated in red:')
    disp(['lonw=' num2str(MODEL_grid.lonw) ', lone=' num2str(MODEL_grid.lone) ', lats=' num2str(MODEL_grid.lats) ', latn=' num2str(MODEL_grid.latn)]);
end

if input('save area? (0 or 1) ')
    gridname=input('save filename (including full path)  to save area (.mat file): ','s');
    disp(['save ' gridname ])
    eval(['save ' gridname ' MODEL_grid'])
end

%% load scale factors and select for geographical areas + interpolate scale factors on north and west face of grid cells 
switch model
    case 'GFDL'
        dxt=readnc(gridfile,'dxt'); % at center
        dyt=readnc(gridfile,'dyt'); % at center
        dyte=readnc(gridfile,'dyte'); % at eastern face of cell
        dxtn=readnc(gridfile,'dxtn'); % at northern face of cell
        dzt=readnc(gridfile,'dz_t'); % at center
        dzc=readnc(gridfile,'dz_c'); % at north WEST corner of cell
        dzt(find(dzt==0))=NaN;
        dzc(find(dzc==0))=NaN;
	disp('default configuration for GFDL defines Corner points at the north west corner of cell')
        disp('cf http://data1.gfdl.noaa.gov:9192/opendap/gfdl_cm2_0/ocean_grid_doc.html')
	disp('warning: CMIP5 GFDL-CM3 defines Corner points at the north east corner of cell !')
	if ~input('use default configuration of GFDL which is Corner point at north west corner of cell? (0 or 1)')
            disp('hence we assume here that Corner point is located at the north east corner of cell')
	    dzc=cat(3,dzc(:,:,end),dzc(:,:,1:end-1));
        end
    case 'CCSM'
        dxt=readnc(gridfile,'DXT')*1e-2; % originally in centimeters >> convert to meters
        dyt=readnc(gridfile,'DYT')*1e-2;  % originally in centimeters >> convert to meters
        dyte=readnc(gridfile,'HTE')*1e-2;  % originally in centimeters >> convert to meters
        dxtn=readnc(gridfile,'HTN')*1e-2;  % originally in centimeters >> convert to meters
        dzt=readnc(gridfile,'dz')*1e-2; % originally in centimeters >> convert to meters
        dzw=dzt; % no partial steps
        dzn=dzt; % no partial steps
    case {'IPSL','NEMO'}
        dxt=readnc(gridfile,'e1t'); % at center
        dyt=readnc(gridfile,'e2t'); % at center
        dyte=readnc(gridfile,'e2u'); % at eastern face of cell
        dxtn=readnc(gridfile,'e1v'); % at northern face of cell
        dzt=readnc(gridfile,'e3t'); % at center
        if ndims(dzt)==2
            dzw=dzt; % no partial steps
            dzn=dzt; % no partial steps
        else
            dze=readnc(gridfile,'e3u'); 
            dzn=readnc(gridfile,'e3v');
            dzw=cat(3,dze(:,:,end),dze(:,:,1:end-1));
        end
    case 'CNRM'
        dxt=readnc(gridfile,'e1t'); % at center
        dyt=readnc(gridfile,'e2t'); % at center
        dyte=readnc(gridfile,'e2u'); % at eastern face of cell
        dxtn=readnc(gridfile,'e1v'); % at northern face of cell
        dzt=readnc(gridfile,'e3t').*double(readnc(gridfile,'tmask')); % at center
        dze=readnc(gridfile,'e3u').*double(readnc(gridfile,'umask')); 
        dzn=readnc(gridfile,'e3v').*double(readnc(gridfile,'vmask'));
        dzw=cat(3,dze(:,:,end),dze(:,:,1:end-1));
    case 'RCHB'
	dxtn=cat(1,0.5*(dxt(2:end,:)+dxt(1:end-1,:)),zeros(1,size(dxt,2)));
	dyte=cat(2,0.5*(dyt(:,2:end)+dyt(:,1:end-1)),zeros(size(dyt,1),1));
	dzw=dzt;
	dze=cat(3,min(dzt(:,:,2:end),dzt(:,:,1:end-1)),zeros(size(dzt,1),size(dzt,2),1));
	dzn=cat(2,min(dzt(:,2:end,:),dzt(:,1:end-1,:)),zeros(size(dzt,1),1,size(dzt,3)));
end

if MODEL_grid.lone<MODEL_grid.lonw    
    MODEL_grid.lont=cat(2,lont(MODEL_grid.lats:MODEL_grid.latn,MODEL_grid.lonw:end)-360,lont(MODEL_grid.lats:MODEL_grid.latn,1:MODEL_grid.lone));
    MODEL_grid.latt=cat(2,latt(MODEL_grid.lats:MODEL_grid.latn,MODEL_grid.lonw:end),latt(MODEL_grid.lats:MODEL_grid.latn,1:MODEL_grid.lone));
    MODEL_grid.bathy=cat(2,bathy(MODEL_grid.lats:MODEL_grid.latn,MODEL_grid.lonw:end),bathy(MODEL_grid.lats:MODEL_grid.latn,1:MODEL_grid.lone));
    MODEL_grid.mask=cat(2,mask(MODEL_grid.lats:MODEL_grid.latn,MODEL_grid.lonw:end),mask(MODEL_grid.lats:MODEL_grid.latn,1:MODEL_grid.lone));
    dxt=cat(2,dxt(MODEL_grid.lats:MODEL_grid.latn,MODEL_grid.lonw:end),dxt(MODEL_grid.lats:MODEL_grid.latn,1:MODEL_grid.lone));
    dxtn=cat(2,dxtn(MODEL_grid.lats:MODEL_grid.latn,MODEL_grid.lonw:end),dxtn(MODEL_grid.lats:MODEL_grid.latn,1:MODEL_grid.lone));
    dyt=cat(2,dyt(MODEL_grid.lats:MODEL_grid.latn,MODEL_grid.lonw:end),dyt(MODEL_grid.lats:MODEL_grid.latn,1:MODEL_grid.lone));
    if MODEL_grid.lone>1
        dytw=cat(2,dyte(MODEL_grid.lats:MODEL_grid.latn,MODEL_grid.lonw-1:end),dyte(MODEL_grid.lats:MODEL_grid.latn,1:MODEL_grid.lone-1));
    else
        dytw=dyte(MODEL_grid.lats:MODEL_grid.latn,MODEL_grid.lonw-1:end);
    end
    if ndims(dzt)>2
        switch model
            case 'GFDL'
                dzt=cat(3,dzt(:,MODEL_grid.lats:MODEL_grid.latn+1,MODEL_grid.lonw-1:end),dzt(:,MODEL_grid.lats:MODEL_grid.latn+1,1:MODEL_grid.lone));
                dzw=0.5*squeeze(nansum(cat(4,dzc(:,2:end,1:end-1),dzc(:,1:end-1,1:end-1)),4)); % cf GFDL userguide
                dzn=0.5*squeeze(nansum(cat(4,dzc(:,2:end,2:end),dzc(:,2:end,1:end-1)),4)); % cf GFDL userguide
                dzt=dzt(:,1:end-1,2:end);
            otherwise
                dzt=cat(3,dzt(:,MODEL_grid.lats:MODEL_grid.latn,MODEL_grid.lonw:end),dzt(:,MODEL_grid.lats:MODEL_grid.latn,1:MODEL_grid.lone));
                dzw=cat(3,dzw(:,MODEL_grid.lats:MODEL_grid.latn,MODEL_grid.lonw:end),dzw(:,MODEL_grid.lats:MODEL_grid.latn,1:MODEL_grid.lone));
                dzn=cat(3,dzn(:,MODEL_grid.lats:MODEL_grid.latn,MODEL_grid.lonw:end),dzn(:,MODEL_grid.lats:MODEL_grid.latn,1:MODEL_grid.lone));
        end
    end
else
    MODEL_grid.lont=lont(MODEL_grid.lats:MODEL_grid.latn,MODEL_grid.lonw:MODEL_grid.lone);
    MODEL_grid.latt=latt(MODEL_grid.lats:MODEL_grid.latn,MODEL_grid.lonw:MODEL_grid.lone);
    MODEL_grid.bathy=bathy(MODEL_grid.lats:MODEL_grid.latn,MODEL_grid.lonw:MODEL_grid.lone);
    MODEL_grid.mask=mask(MODEL_grid.lats:MODEL_grid.latn,MODEL_grid.lonw:MODEL_grid.lone);
    if max(max(MODEL_grid.lont>360))
        MODEL_grid.lont=MODEL_grid.lont-360;
    end
    if min(min(MODEL_grid.lont<-360))
        MODEL_grid.lont=MODEL_grid.lont+360;
    end
    dxt=dxt(MODEL_grid.lats:MODEL_grid.latn,MODEL_grid.lonw:MODEL_grid.lone);
    dxtn=dxtn(MODEL_grid.lats:MODEL_grid.latn,MODEL_grid.lonw:MODEL_grid.lone);
    dyt=dyt(MODEL_grid.lats:MODEL_grid.latn,MODEL_grid.lonw:MODEL_grid.lone);
    if MODEL_grid.lonw>1
        dytw=dyte(MODEL_grid.lats:MODEL_grid.latn,MODEL_grid.lonw-1:MODEL_grid.lone-1);
    else
        dytw=cat(2,dyte(MODEL_grid.lats:MODEL_grid.latn,end),dyte(MODEL_grid.lats:MODEL_grid.latn,MODEL_grid.lonw:MODEL_grid.lone-1));
    end
    if ndims(dzt)>2
        if model=='GFDL'
            if MODEL_grid.lone<size(mask,2)
                dzc=dzc(:,MODEL_grid.lats-1:MODEL_grid.latn,MODEL_grid.lonw:MODEL_grid.lone+1);
            else
                dzc=cat(3,dzc(:,MODEL_grid.lats-1:MODEL_grid.latn,MODEL_grid.lonw:MODEL_grid.lone),dzc(:,MODEL_grid.lats-1:MODEL_grid.latn,1));
            end
            dzw=0.5*squeeze(nansum(cat(4,dzc(:,2:end,1:end-1),dzc(:,1:end-1,1:end-1)),4));
            dzn=0.5*squeeze(nansum(cat(4,dzc(:,2:end,2:end),dzc(:,2:end,1:end-1)),4));
            dzt=dzt(:,MODEL_grid.lats:MODEL_grid.latn,MODEL_grid.lonw:MODEL_grid.lone);
        else
            dzt=dzt(:,MODEL_grid.lats:MODEL_grid.latn,MODEL_grid.lonw:MODEL_grid.lone);
            dzw=dzw(:,MODEL_grid.lats:MODEL_grid.latn,MODEL_grid.lonw:MODEL_grid.lone);
            dzn=dzn(:,MODEL_grid.lats:MODEL_grid.latn,MODEL_grid.lonw:MODEL_grid.lone);
        end
    end
end

if ndims(dzt)==2
    nz=length(dzt);
    [nj,ni]=size(dxt);
    dzt=repmat(dzt,[1 nj ni]);
    dzw=repmat(dzw,[1 nj ni]);
    dzn=repmat(dzn,[1 nj ni]);
else
    [nz,nj,ni]=size(dzt);    
end

areaW=dzw.*repmat(reshape(dytw,[1 nj ni]),[nz 1 1]); % in m2
areaN=dzn.*repmat(reshape(dxtn,[1 nj ni]),[nz 1 1]); % in m2
areaW(find(isnan(areaW)))=0;
areaN(find(isnan(areaN)))=0;
volume=dzt.*repmat(reshape(dxt.*dyt,[1 nj ni]),[nz 1 1]); % in m3
volume(find(isnan(volume)))=0;
surface=dxt.*dyt; % in m2

% check longitude for cutting the map (avoid cutting in the middle of a region of interest)
disclon=180;
    if ~input('ok with cutting the map at longitude 180 ? (0 or 1) ');
        disclon=input('enter longitude for cutting the map (from 0 to 360): ');
    end
MODEL_grid.lont(find(MODEL_grid.lont>disclon))=MODEL_grid.lont(find(MODEL_grid.lont>disclon))-360;

figure(11)
clf
atracer=MODEL_grid.bathy; atracer(find(MODEL_grid.mask==0))=NaN;
h=pcolor(MODEL_grid.lont,MODEL_grid.latt,atracer);
set(h,'linestyle','none')
xlabel('longitude')
ylabel('latitude')
hc=colorbar;
ylabel(hc,'Bathymetry (m)');

%% get endpoints of sections in the North Atlantic
if ans_atl || input('load predefined lat/lon of section endpoints? (0 or 1) ')
    if ans_atl
        eval(['load sections_NA.mat'])
    else
        file=input('enter filename (including full path): ','s');
        eval(['load ' file])
    end
    nsec=length(sections);
    for sec=1:nsec
        MODEL_sections(sec).name=sections(sec).name;
        [vecj,veci]=locingrid(sections(sec).lon,sections(sec).lat,MODEL_grid.lont,MODEL_grid.latt);
        sections(sec).i=veci;
        sections(sec).j=vecj;
        if sections(sec).i(end)<sections(sec).i(1)
            sections(sec).i=fliplr(sections(sec).i);
            sections(sec).j=fliplr(sections(sec).j);
            sections(sec).dir=flipud(sections(sec).dir);
        end
    end
% built-in corrections for some models for sections in North Atlantic
    if ans_atl
        if input('use built-in correction of sections from JD --- only if proper GRID area selected --- (0 or 1) ')
	    run section_corrections_NA
        end
    end

    figure(11); hold on
    for sec=1:nsec
        plot(sections(sec).lon,sections(sec).lat,'k.')
        plot(sections(sec).lon,sections(sec).lat,'k')
    end
    figure(12); clf; hold on
    contour(MODEL_grid.mask,[1 1],'k')
    for sec=1:nsec
        plot(sections(sec).i,sections(sec).j,'r.')
        plot(sections(sec).i,sections(sec).j,'r')
    end
    title('end points of sections')
    grid on
    xlabel('grid points')
    ylabel('grid points')
end

while input('add section? (0 or 1) ');
    if exist('MODEL_sections','var')
        nsec=length(MODEL_sections);
    else
        nsec=0;
        figure(12)
        clf
        contour(MODEL_grid.mask,[1 1],'k')
        hold on
        title('end points of sections')
        grid on
        xlabel('grid points')
        ylabel('grid points')
    end
    MODEL_sections(nsec+1).name=input('short name for section (3 letters only, a25 for example): ','s');
    while length(MODEL_sections(nsec+1).name)~=3
        MODEL_sections(nsec+1).name=input('please type again the name for section : it must be 3 letters (a25 for example)... ','s');
    end
    disp('select end points and corners by clicking on the figure (within black dots), then press return key')
    figure(11)
    hold on
    plot(MODEL_grid.lont(1,:),MODEL_grid.latt(1,:),'k.');
    plot(MODEL_grid.lont(end,:),MODEL_grid.latt(end,:),'k.');
    plot(MODEL_grid.lont(:,1),MODEL_grid.latt(:,1),'k.');
    plot(MODEL_grid.lont(:,end),MODEL_grid.latt(:,end),'k.');
    [lon,lat]=ginputJD;
    plot(lon,lat,'r')
    [vecj,veci]=locingrid(lon,lat,MODEL_grid.lont,MODEL_grid.latt);
    sections(nsec+1).i=veci;
    sections(nsec+1).j=vecj;

    figure(12)
    plot(sections(end).i,sections(end).j,'r.')
    plot(sections(end).i,sections(end).j,'r')
    for l=1:length(sections(end).i)-1
        text(.5*(sections(end).i(l+1)+sections(end).i(l)),.5*(sections(end).j(l+1)+sections(end).j(l)),num2str(l))
    end
    
    disp(['enter directions (NW, NE, SW or SE) for the segment(s) of section ' MODEL_sections(nsec+1).name])
    disp('(directions being defined in distorted grid)')
    disp('(press enter after each segment)')
    sections(nsec+1).dir=[];
    for l=1:length(sections(nsec+1).i)-1
        temp=input(['segment #' num2str(l) ': '],'s');
        while length(temp)>2
            temp=input('(re-enter only 2 letters: NE NW SE or SW): ','s');
        end
        sections(nsec+1).dir=cat(1,sections(nsec+1).dir,temp);
    end   
    
    if sections(nsec+1).i(end)<sections(nsec+1).i(1)
        sections(nsec+1).i=fliplr(sections(nsec+1).i);
        sections(nsec+1).j=fliplr(sections(nsec+1).j);
        sections(nsec+1).dir=flipud(sections(nsec+1).dir);
    end
end

figure(12); clf; hold on
contour(MODEL_grid.mask,[1 1],'k')
for sec=1:length(sections)
    plot(sections(sec).i,sections(sec).j,'r.')
    plot(sections(sec).i,sections(sec).j,'r')
    text(.5*(sections(sec).i(2)+sections(sec).i(1)),.5*(sections(sec).j(2)+sections(sec).j(1)),MODEL_sections(sec).name,'color','r','fontweight','bold')
end
title('end points of sections')
grid on
xlabel('grid points')
ylabel('grid points')

% check for each section whether endpoint is in land
nsec=length(sections);
for sec=1:nsec
    test1=MODEL_grid.mask(sections(sec).j(1),sections(sec).i(1));
    test2=MODEL_grid.mask(sections(sec).j(end),sections(sec).i(end));
    if ~test1 && ~test2
    else
        if test1
            if sections(sec).i(1)-1>0 & ~MODEL_grid.mask(sections(sec).j(1),sections(sec).i(1)-1)
                sections(sec).i(1)=sections(sec).i(1)-1;
            else
                if sections(sec).j(1)-1>0 & ~MODEL_grid.mask(sections(sec).j(1)-1,sections(sec).i(1))
                    sections(sec).j(1)=sections(sec).j(1)-1;
                else
                    if sections(sec).j(1)+1<size(MODEL_grid.mask,1) & ~MODEL_grid.mask(sections(sec).j(1)+1,sections(sec).i(1))
                        sections(sec).j(1)=sections(sec).j(1)+1;
                    else
                        disp(['section ' MODEL_sections(sec).name ' : 1st point in water'])
                        ans1=input('change location of point? (0 or 1) ');
                        if ans1
                            disp(['j-index=' num2str(sections(sec).j(1)) ' , i-index=' num2str(sections(sec).i(1)) ])
                            sections(sec).j(1)=input('new j-index= ');
                            sections(sec).i(1)=input('new i-index= ');
                        end
                    end
                end
            end
        end
        if test2>0
            if sections(sec).i(end)-1>0 & ~MODEL_grid.mask(sections(sec).j(end),sections(sec).i(end)-1)
                sections(sec).i(end)=sections(sec).i(end)-1;
            else
                if sections(sec).j(end)-1>0 & ~MODEL_grid.mask(sections(sec).j(end)-1,sections(sec).i(end))
                    sections(sec).j(end)=sections(sec).j(end)-1;
                else
                    if sections(sec).j(end)+1<size(MODEL_grid.mask,1) &  ~MODEL_grid.mask(sections(sec).j(end)+1,sections(sec).i(end))
                        sections(sec).j(end)=sections(sec).j(end)+1;
                    else
                        disp(['section ' MODEL_sections(sec).name ' : last point in water'])
                        ans1=input('change location of point? (0 or 1) ');
                        if ans1
                            disp(['j-index=' num2str(sections(sec).j(end)) ' , i-index=' num2str(sections(sec).i(end)) ])
                            sections(sec).j(end)=input('new j-index= ');
                            sections(sec).i(end)=input('new i-index= ');
                        end
                    end
                end
            end
        end
    end
end

figure(12)
clf
contour(MODEL_grid.mask,[1 1],'k')
hold on
for sec=1:nsec
    plot(sections(sec).i,sections(sec).j,'r.')
    plot(sections(sec).i,sections(sec).j,'r')
    text(.5*(sections(sec).i(2)+sections(sec).i(1)),.5*(sections(sec).j(2)+sections(sec).j(1)),MODEL_sections(sec).name,'color','r','fontweight','bold')
end
title('end points of sections')
grid on
xlabel('grid points')
ylabel('grid points')

%% get all points along sections + information for all points
earthell=almanac('earth','ellipsoid');
nsec=length(sections);
for sec=1:nsec
    [vecj,veci]=secingrid(sections(sec).i(1),sections(sec).j(1),sections(sec).i(2),sections(sec).j(2));
    [faces,newveci,newvecj,orientation]=facesinsec(veci,vecj,sections(sec).dir(1,:));
    MODEL_sections(sec).veci=newveci;
    MODEL_sections(sec).vecj=newvecj;
    MODEL_sections(sec).faces=faces;
    MODEL_sections(sec).orient=orientation;
    nl1=floor(length(newveci)/2);
    if length(sections(sec).i)>2
        for l=3:length(sections(sec).i)
            [vecj,veci]=secingrid(sections(sec).i(l-1),sections(sec).j(l-1),sections(sec).i(l),sections(sec).j(l));
            [faces,newveci,newvecj,orientation]=facesinsec(veci,vecj,sections(sec).dir(l-1,:));
            [finalfaces,finalveci,finalvecj,finalorient]=consec(MODEL_sections(sec).veci,MODEL_sections(sec).vecj,MODEL_sections(sec).faces,MODEL_sections(sec).orient,newveci,newvecj,faces,orientation);
            MODEL_sections(sec).veci=finalveci;
            MODEL_sections(sec).vecj=finalvecj;
            MODEL_sections(sec).faces=finalfaces;
            MODEL_sections(sec).orient=finalorient;
            nl2=floor(length(newveci)/2);
        end
    end

    % in case section is closed
    if MODEL_sections(sec).veci(1)==MODEL_sections(sec).veci(end) && MODEL_sections(sec).vecj(1)==MODEL_sections(sec).vecj(end)
        [finalfaces,finalveci,finalvecj,finalorient]=consec(MODEL_sections(sec).veci(end-nl2:end),MODEL_sections(sec).vecj(end-nl2:end),MODEL_sections(sec).faces(end-nl2:end),MODEL_sections(sec).orient(end-nl2:end),...
                                                    MODEL_sections(sec).veci(1:nl1),MODEL_sections(sec).vecj(1:nl1),MODEL_sections(sec).faces(1:nl1),MODEL_sections(sec).orient(1:nl1));
        MODEL_sections(sec).veci=[MODEL_sections(sec).veci(nl1+1:end-nl2-1) finalveci];
        MODEL_sections(sec).vecj=[MODEL_sections(sec).vecj(nl1+1:end-nl2-1) finalvecj];
        MODEL_sections(sec).faces=[MODEL_sections(sec).faces(nl1+1:end-nl2-1);finalfaces];
        MODEL_sections(sec).orient=[MODEL_sections(sec).orient(nl1+1:end-nl2-1) finalorient];
    end

    MODEL_sections(sec).areavect=areainsec(MODEL_sections(sec).veci,MODEL_sections(sec).vecj,MODEL_sections(sec).faces,areaW,areaN);
    MODEL_sections(sec).lengthvect=lengthinsec(MODEL_sections(sec).veci,MODEL_sections(sec).vecj,MODEL_sections(sec).faces,dytw,dxtn);
    MODEL_sections(sec).depthvect=areainsec(MODEL_sections(sec).veci,MODEL_sections(sec).vecj,MODEL_sections(sec).faces,dzw,dzn);

    % length in km along section for visualization
    nl=length(find(~isnan(MODEL_sections(sec).veci)));
    [vecj,veci]=nodouble(MODEL_sections(sec).veci(1:nl),MODEL_sections(sec).vecj(1:nl));    
    MODEL_sections(sec).lvect(1)=0;
    for l=2:length(veci)
        MODEL_sections(sec).lvect(l)=MODEL_sections(sec).lvect(l-1)+distance(latt(vecj(l),veci(l)),lont(vecj(l),veci(l)),latt(vecj(l-1),veci(l-1)),lont(vecj(l-1),veci(l-1)),earthell);
    end

    % prepare space to load data
    MODEL_sections(sec).vect=NaN*ones(1,nz,length(MODEL_sections(sec).veci));
    MODEL_sections(sec).vecs=NaN*ones(1,nz,length(MODEL_sections(sec).veci));
    MODEL_sections(sec).vecv=NaN*ones(1,nz,length(MODEL_sections(sec).veci));
end

% in North Atlantic, check connection between ifo and fso: if no land point at crossover,
% remove the end point of section ifo if same as start point of section fso
for l=1:length(MODEL_sections)
    vecname(l,:)=MODEL_sections(l).name;
end
ifo=find((vecname(:,1)=='i')&(vecname(:,2)=='f')&(vecname(:,3)=='o'));
fso=find((vecname(:,1)=='f')&(vecname(:,2)=='s')&(vecname(:,3)=='o'));
if length(ifo)>0 && length(fso)>0
    if (MODEL_sections(ifo).veci(end)==MODEL_sections(fso).veci(1)) & (MODEL_sections(ifo).vecj(end)==MODEL_sections(fso).vecj(1))
        MODEL_sections(ifo).veci=MODEL_sections(ifo).veci(1:end-1);
        MODEL_sections(ifo).vecj=MODEL_sections(ifo).vecj(1:end-1);
        MODEL_sections(ifo).faces=MODEL_sections(ifo).faces(1:end-1);
        MODEL_sections(ifo).orient=MODEL_sections(ifo).orient(1:end-1);
        MODEL_sections(ifo).areavect=MODEL_sections(ifo).areavect(:,1:end-1);
        MODEL_sections(ifo).lengthvect=MODEL_sections(ifo).lengthvect(1:end-1);
        MODEL_sections(ifo).depthvect=MODEL_sections(ifo).depthvect(:,1:end-1);
        MODEL_sections(ifo).lvect=MODEL_sections(ifo).lvect(1:end-1);
        MODEL_sections(ifo).vect=MODEL_sections(ifo).vect(:,:,1:end-1);
        MODEL_sections(ifo).vecs=MODEL_sections(ifo).vecs(:,:,1:end-1);
        MODEL_sections(ifo).vecv=MODEL_sections(ifo).vecv(:,:,1:end-1);
    end
end

figure(12)
clf
contour(MODEL_grid.mask,[1 1],'k')
hold on
for sec=1:nsec
    plotsecfaces(MODEL_sections(sec).veci,MODEL_sections(sec).vecj,MODEL_sections(sec).faces,MODEL_sections(sec).orient,'b');
    text(.5*(sections(sec).i(2)+sections(sec).i(1)),.5*(sections(sec).j(2)+sections(sec).j(1)),MODEL_sections(sec).name,'color','b','fontweight','bold')
end
title('sections in grid')
xlabel('grid points')
ylabel('grid points')

disp('please check carefully that the direction of transport across each section is correct using the dots : ')
disp('the dots may be viewed as the head of arrows normal to each section,')
disp('heading in the direction defined as positive for the mass transport.')
count=1;
while ~input('ok with the direction of each section ? (0 or 1) ')
    if count==1
        disp(['recall name of sections:'])
        for sec=1:length(MODEL_sections)
            disp(MODEL_sections(sec).name)
        end
        count=count+1;
    end
    wrongdirsec_allnames=input('enter list of sections with incorrect direction (list of names separated by space): ','s');
    wrongdirsec=[];
    temp=find(wrongdirsec_allnames==' ');
    temp=cat(2,0,temp);
    for ind=1:length(temp)
        wrongdirsec=cat(1,wrongdirsec,findsecnum(MODEL_sections,wrongdirsec_allnames(temp(ind)+1:temp(ind)+3)));
    end

    for sec=1:length(wrongdirsec)
	disp(['enter directions (NW, NE, SW or SE) for the segment(s) of section ' MODEL_sections(wrongdirsec(sec)).name])
       	disp('(press enter after each segment)')
       	for l=1:length(sections(wrongdirsec(sec)).i)-1
            text(.5*(sections(wrongdirsec(sec)).i(l+1)+sections(wrongdirsec(sec)).i(l)),.5*(sections(wrongdirsec(sec)).j(l+1)+sections(wrongdirsec(sec)).j(l)),num2str(l))
            temp=input(['segment #' num2str(l) ': '],'s');
            while length(temp)>2
                temp=input('(re-enter only 2 letters: NE NW SE or SW): ','s');
            end
            if sections(wrongdirsec(sec)).dir(1)~=temp(1)
	  	MODEL_sections(wrongdirsec(sec)).orient(find(MODEL_sections(wrongdirsec(sec)).faces=='N'))=-MODEL_sections(wrongdirsec(sec)).orient(find(MODEL_sections(wrongdirsec(sec)).faces=='N'));
	    end
            if sections(wrongdirsec(sec)).dir(2)~=temp(2)
		MODEL_sections(wrongdirsec(sec)).orient(find(MODEL_sections(wrongdirsec(sec)).faces=='W'))=-MODEL_sections(wrongdirsec(sec)).orient(find(MODEL_sections(wrongdirsec(sec)).faces=='W'));
	    end
        end
        
	figure(12); clf; hold on
	contour(MODEL_grid.mask,[1 1],'k')
	for sec=1:nsec
    	    plotsecfaces(MODEL_sections(sec).veci,MODEL_sections(sec).vecj,MODEL_sections(sec).faces,MODEL_sections(sec).orient,'b');
    	    text(.5*(sections(sec).i(2)+sections(sec).i(1)),.5*(sections(sec).j(2)+sections(sec).j(1)),MODEL_sections(sec).name,'color','b','fontweight','bold')
	end
	title('sections in grid')
	xlabel('grid points')
	ylabel('grid points')
    end
end
 
%% get areas in the North Atlantic
if ans_atl==1 && input('select areas for subpolar gyre and nordic seas? (0 or 1) ')
        
    switch model
	case {'IPSL','NEMO'}
	    [wstj,wsti]=locingrid(-2,55,MODEL_grid.lont,MODEL_grid.latt);
	    [hud42n_vecj,hud42n_veci]=secingrid(MODEL_sections(7).veci(1),MODEL_sections(7).vecj(1),MODEL_sections(1).veci(1),MODEL_sections(1).vecj(1));
	    [s42nwst_vecj,s42nwst_veci]=secingrid(MODEL_sections(1).veci(end),MODEL_sections(1).vecj(end),wsti,wstj);
	    subpolar_boundary_south_i=[MODEL_sections(7).veci(5:-1:1),hud42n_veci(2:end-1),MODEL_sections(1).veci,s42nwst_veci(2:end)];
	    subpolar_boundary_south_j=[MODEL_sections(7).vecj(5:-1:1),hud42n_vecj(2:end-1),MODEL_sections(1).vecj,s42nwst_vecj(2:end)];
	    [hudbaf_vecj,hudbaf_veci]=secingrid(MODEL_sections(7).veci(6),MODEL_sections(7).vecj(6),MODEL_sections(8).veci(1),MODEL_sections(8).vecj(1));
	    [bafdso_vecj,bafdso_veci]=secingrid(MODEL_sections(8).veci(end),MODEL_sections(8).vecj(end),MODEL_sections(9).veci(1),MODEL_sections(9).vecj(1));
	    [dsoifo_vecj,dsoifo_veci]=secingrid(MODEL_sections(9).veci(end),MODEL_sections(9).vecj(end),MODEL_sections(10).veci(1),MODEL_sections(10).vecj(1));
	    [fsowst_vecj,fsowst_veci]=secingrid(MODEL_sections(11).veci(end),MODEL_sections(11).vecj(end),wsti,wstj);

	    subpolar_boundary_north_i=[MODEL_sections(7).veci(6:end),hudbaf_veci(2:end-1),MODEL_sections(8).veci,bafdso_veci(2:end-1),MODEL_sections(9).veci,dsoifo_veci(2:end-1),MODEL_sections(10).veci,MODEL_sections(11).veci,fsowst_veci(2:end)];
	    subpolar_boundary_north_j=[MODEL_sections(7).vecj(6:end),hudbaf_vecj(2:end-1),MODEL_sections(8).vecj,bafdso_vecj(2:end-1),MODEL_sections(9).vecj,dsoifo_vecj(2:end-1),MODEL_sections(10).vecj,MODEL_sections(11).vecj,fsowst_vecj(2:end)];
	    [dsonon_vecj,dsonon_veci]=secingrid(MODEL_sections(9).veci(1),MODEL_sections(9).vecj(1),MODEL_sections(5).veci(1),MODEL_sections(5).vecj(1));

	    nordic_boundary_north_i=[dsonon_veci(1:end-1),MODEL_sections(5).veci,MODEL_sections(4).veci];
	    nordic_boundary_north_j=[dsonon_vecj(1:end-1),MODEL_sections(5).vecj,MODEL_sections(4).vecj];
	    [dsoifo_vecj,dsoifo_veci]=secingrid(MODEL_sections(9).veci(end),MODEL_sections(9).vecj(end),MODEL_sections(10).veci(1),MODEL_sections(10).vecj(1));
	    [fsomdn_vecj,fsomdn_veci]=secingrid(MODEL_sections(11).veci(end),MODEL_sections(11).vecj(end),MODEL_sections(13).veci(1),MODEL_sections(13).vecj(1));
      	    [mdnbar_vecj,mdnbar_veci]=secingrid(MODEL_sections(13).veci(end),MODEL_sections(13).vecj(end),MODEL_sections(4).veci(end),MODEL_sections(4).vecj(end));
 
	    nordic_boundary_south_i=[MODEL_sections(9).veci,dsoifo_veci(2:end-1),MODEL_sections(10).veci,MODEL_sections(11).veci,fsomdn_veci(2:end-1),MODEL_sections(13).veci,mdnbar_veci(2:end)];
	    nordic_boundary_south_j=[MODEL_sections(9).vecj,dsoifo_vecj(2:end-1),MODEL_sections(10).vecj,MODEL_sections(11).vecj,fsomdn_vecj(2:end-1),MODEL_sections(13).vecj,mdnbar_vecj(2:end)];

	case 'CNRM'
	    [hud42n_vecj,hud42n_veci]=secingrid(MODEL_sections(7).veci(1),MODEL_sections(7).vecj(1),MODEL_sections(1).veci(1),MODEL_sections(1).vecj(1));
	    [s42nits_vecj,s42nits_veci]=secingrid(MODEL_sections(1).veci(end),MODEL_sections(1).vecj(end),MODEL_sections(12).veci(1)-1,MODEL_sections(12).vecj(1)-1);
	    subpolar_boundary_south_i=[MODEL_sections(7).veci(5:-1:1),hud42n_veci(2:end-1),MODEL_sections(1).veci,s42nits_veci(2:end),MODEL_sections(12).veci(2:end)-1];
	    subpolar_boundary_south_j=[MODEL_sections(7).vecj(5:-1:1),hud42n_vecj(2:end-1),MODEL_sections(1).vecj,s42nits_vecj(2:end),MODEL_sections(12).vecj(2:end)-1];
		
	    [hudbaf_vecj,hudbaf_veci]=secingrid(MODEL_sections(7).veci(end)-1,MODEL_sections(7).vecj(end)-1,MODEL_sections(8).veci(1),MODEL_sections(8).vecj(1));
	    [bafdso_vecj,bafdso_veci]=secingrid(MODEL_sections(8).veci(end),MODEL_sections(8).vecj(end),MODEL_sections(9).veci(1),MODEL_sections(9).vecj(1));
	    [dsoifo_vecj,dsoifo_veci]=secingrid(MODEL_sections(9).veci(end),MODEL_sections(9).vecj(end),MODEL_sections(10).veci(1),MODEL_sections(10).vecj(1));
	    subpolar_boundary_north_i=[MODEL_sections(7).veci(6:end)-1,hudbaf_veci(2:end-1),MODEL_sections(8).veci,bafdso_veci(2:end-1),MODEL_sections(9).veci,dsoifo_veci(2:end-1),MODEL_sections(10).veci,MODEL_sections(11).veci];
	    subpolar_boundary_north_j=[MODEL_sections(7).vecj(6:end)-1,hudbaf_vecj(2:end-1),MODEL_sections(8).vecj,bafdso_vecj(2:end-1),MODEL_sections(9).vecj,dsoifo_vecj(2:end-1),MODEL_sections(10).vecj,MODEL_sections(11).vecj];

	    [dsonon_vecj,dsonon_veci]=secingrid(MODEL_sections(9).veci(1),MODEL_sections(9).vecj(1),MODEL_sections(5).veci(1),MODEL_sections(5).vecj(1));
	    nordic_boundary_north_i=[dsonon_veci(1:end-1),MODEL_sections(5).veci,MODEL_sections(4).veci];
	    nordic_boundary_north_j=[dsonon_vecj(1:end-1),MODEL_sections(5).vecj,MODEL_sections(4).vecj];

	    [dsoifo_vecj,dsoifo_veci]=secingrid(MODEL_sections(9).veci(end),MODEL_sections(9).vecj(end),MODEL_sections(10).veci(1),MODEL_sections(10).vecj(1));
	    [fsomdn_vecj,fsomdn_veci]=secingrid(MODEL_sections(11).veci(end),MODEL_sections(11).vecj(end),MODEL_sections(13).veci(1),MODEL_sections(13).vecj(1));
	    [mdnbar_vecj,mdnbar_veci]=secingrid(MODEL_sections(13).veci(end),MODEL_sections(13).vecj(end),MODEL_sections(4).veci(end),MODEL_sections(4).vecj(end));
	    nordic_boundary_south_i=[MODEL_sections(9).veci,dsoifo_veci(2:end-1),MODEL_sections(10).veci,MODEL_sections(11).veci,fsomdn_veci(2:end-1),MODEL_sections(13).veci,mdnbar_veci(2:end)];
	    nordic_boundary_south_j=[MODEL_sections(9).vecj,dsoifo_vecj(2:end-1),MODEL_sections(10).vecj,MODEL_sections(11).vecj,fsomdn_vecj(2:end-1),MODEL_sections(13).vecj,mdnbar_vecj(2:end)];

	case 'GFDL'
	    [hud42n_vecj,hud42n_veci]=secingrid(MODEL_sections(7).veci(end),MODEL_sections(7).vecj(end),MODEL_sections(1).veci(1),MODEL_sections(1).vecj(1));
	    [faces,hud42n_veci,hud42n_vecj]=facesinsec(hud42n_veci,hud42n_vecj,'NE');
	    [s42nits_vecj,s42nits_veci]=secingrid(MODEL_sections(1).veci(end),MODEL_sections(1).vecj(end),MODEL_sections(12).veci(1),MODEL_sections(12).vecj(1));
	    [faces,s42nits_veci,s42nits_vecj]=facesinsec(s42nits_veci,s42nits_vecj,'NW');
	    subpolar_boundary_south_i=[MODEL_sections(7).veci,hud42n_veci(2:end-1),MODEL_sections(1).veci,s42nits_veci(2:end-1),MODEL_sections(12).veci];
	    subpolar_boundary_south_j=[MODEL_sections(7).vecj,hud42n_vecj(2:end-1),MODEL_sections(1).vecj,s42nits_vecj(2:end-1),MODEL_sections(12).vecj];

	    [hudbaf_vecj,hudbaf_veci]=secingrid(MODEL_sections(7).veci(1),MODEL_sections(7).vecj(1),MODEL_sections(8).veci(1),MODEL_sections(8).vecj(1));
	    [bafdso_vecj,bafdso_veci]=secingrid(MODEL_sections(8).veci(end),MODEL_sections(8).vecj(end),MODEL_sections(9).veci(1),MODEL_sections(9).vecj(1));
	    [dsoifo_vecj,dsoifo_veci]=secingrid(MODEL_sections(9).veci(end),MODEL_sections(9).vecj(end),MODEL_sections(10).veci(1),MODEL_sections(10).vecj(1));
	    [fsoits_vecj,fsoits_veci]=secingrid(MODEL_sections(11).veci(end),MODEL_sections(11).vecj(end),MODEL_sections(12).veci(end),MODEL_sections(12).vecj(end));
	    subpolar_boundary_north_i=[hudbaf_veci(1:end-1),MODEL_sections(8).veci,bafdso_veci(2:end-1),MODEL_sections(9).veci,dsoifo_veci(2:end-1),MODEL_sections(10).veci,MODEL_sections(11).veci,fsoits_veci(2:end)];
	    subpolar_boundary_north_j=[hudbaf_vecj(1:end-1),MODEL_sections(8).vecj,bafdso_vecj(2:end-1),MODEL_sections(9).vecj,dsoifo_vecj(2:end-1),MODEL_sections(10).vecj,MODEL_sections(11).vecj,fsoits_vecj(2:end)];
    
	    [dsonon_vecj,dsonon_veci]=secingrid(MODEL_sections(9).veci(1),MODEL_sections(9).vecj(1),MODEL_sections(5).veci(1),MODEL_sections(5).vecj(1));
	    [faces,dsonon_veci,dsonon_vecj]=facesinsec(dsonon_veci,dsonon_vecj,'NW');
	    nordic_boundary_north_i=[dsonon_veci(1:end-1),MODEL_sections(5).veci,MODEL_sections(4).veci];
	    nordic_boundary_north_j=[dsonon_vecj(1:end-1),MODEL_sections(5).vecj,MODEL_sections(4).vecj];

	    [fsomdn_vecj,fsomdn_veci]=secingrid(MODEL_sections(11).veci(end),MODEL_sections(11).vecj(end),MODEL_sections(13).veci(1),MODEL_sections(13).vecj(1));
	    [faces,fsomdn_veci,fsomdn_vecj]=facesinsec(fsomdn_veci,fsomdn_vecj,'NE');
	    [mdnbar_vecj,mdnbar_veci]=secingrid(MODEL_sections(13).veci(end),MODEL_sections(13).vecj(end),MODEL_sections(4).veci(end),MODEL_sections(4).vecj(end));
	    [faces,mdnbar_veci,mdnbar_vecj]=facesinsec(mdnbar_veci,mdnbar_vecj,'NW');
	    nordic_boundary_south_i=[MODEL_sections(9).veci,dsoifo_veci(2:end-1),MODEL_sections(10).veci,MODEL_sections(11).veci,fsomdn_veci(2:end-1),MODEL_sections(13).veci,mdnbar_veci(2:end)];
	    nordic_boundary_south_j=[MODEL_sections(9).vecj,dsoifo_vecj(2:end-1),MODEL_sections(10).vecj,MODEL_sections(11).vecj,fsomdn_vecj(2:end-1),MODEL_sections(13).vecj,mdnbar_vecj(2:end)];

    	case 'CCSM'
	    % WESTernmost point to consider
	    [jw,iw]=locingrid(-70,66,MODEL_grid.lont,MODEL_grid.latt);
	    [esthud_vecj,esthud_veci]=secingrid(iw,jw,MODEL_sections(7).veci(1),MODEL_sections(7).vecj(1));
	    [faces,esthud_veci,esthud_vecj]=facesinsec(esthud_veci,esthud_vecj,'NE');
	    [estbaf_vecj,estbaf_veci]=secingrid(iw,jw,MODEL_sections(8).veci(1),MODEL_sections(8).vecj(1));
	    [faces,estbaf_veci,estbaf_vecj]=facesinsec(estbaf_veci,estbaf_vecj,'SE');
	    [hud42n_vecj,hud42n_veci]=secingrid(MODEL_sections(7).veci(end),MODEL_sections(7).vecj(end),MODEL_sections(1).veci(1),MODEL_sections(1).vecj(1));
	    [faces,hud42n_veci,hud42n_vecj]=facesinsec(hud42n_veci,hud42n_vecj,'NE');
	    [s42nits_vecj,s42nits_veci]=secingrid(MODEL_sections(1).veci(end),MODEL_sections(1).vecj(end),MODEL_sections(12).veci(1),MODEL_sections(12).vecj(1));
	    [faces,s42nits_veci,s42nits_vecj]=facesinsec(s42nits_veci,s42nits_vecj,'NW');
	    subpolar_boundary_south_i=[esthud_veci(1:end-1),MODEL_sections(7).veci,hud42n_veci(2:end-1),MODEL_sections(1).veci,s42nits_veci(2:end-1),MODEL_sections(12).veci];
	    subpolar_boundary_south_j=[esthud_vecj(1:end-1),MODEL_sections(7).vecj,hud42n_vecj(2:end-1),MODEL_sections(1).vecj,s42nits_vecj(2:end-1),MODEL_sections(12).vecj];

	    [bafdso_vecj,bafdso_veci]=secingrid(MODEL_sections(8).veci(end),MODEL_sections(8).vecj(end),MODEL_sections(9).veci(1),MODEL_sections(9).vecj(1));
	    [dsoifo_vecj,dsoifo_veci]=secingrid(MODEL_sections(9).veci(end),MODEL_sections(9).vecj(end),MODEL_sections(10).veci(1),MODEL_sections(10).vecj(1));
	    [fsoits_vecj,fsoits_veci]=secingrid(MODEL_sections(11).veci(end),MODEL_sections(11).vecj(end),MODEL_sections(12).veci(end),MODEL_sections(12).vecj(end));
	    subpolar_boundary_north_i=[estbaf_veci(1:end-1),MODEL_sections(8).veci,bafdso_veci(2:end-1),MODEL_sections(9).veci,dsoifo_veci(2:end-1),MODEL_sections(10).veci,MODEL_sections(11).veci,fsoits_veci(2:end)];
	    subpolar_boundary_north_j=[estbaf_vecj(1:end-1),MODEL_sections(8).vecj,bafdso_vecj(2:end-1),MODEL_sections(9).vecj,dsoifo_vecj(2:end-1),MODEL_sections(10).vecj,MODEL_sections(11).vecj,fsoits_vecj(2:end)];

	    % northernmost point
	    [dsonot_vecj,dsonot_veci]=secingrid(MODEL_sections(9).veci(1),MODEL_sections(9).vecj(1),MODEL_sections(6).veci(1),MODEL_sections(5).vecj(1));
	    [faces,dsonot_veci,dsonot_vecj]=facesinsec(dsonot_veci,dsonot_vecj,'SE');
	    [notnon_vecj,notnon_veci]=secingrid(MODEL_sections(6).veci(1),MODEL_sections(5).vecj(1),MODEL_sections(5).veci(1),MODEL_sections(5).vecj(1));
	    [faces,notnon_veci,notnon_vecj]=facesinsec(notnon_veci,notnon_vecj,'SE');

	    nordic_boundary_north_i=[dsonot_veci(1:end-1),notnon_veci(1:end-1),MODEL_sections(5).veci];
	    nordic_boundary_north_j=[dsonot_vecj(1:end-1),notnon_vecj(1:end-1),MODEL_sections(5).vecj];

	    [fsomdn_vecj,fsomdn_veci]=secingrid(MODEL_sections(11).veci(end),MODEL_sections(11).vecj(end),MODEL_sections(13).veci(1),MODEL_sections(13).vecj(1));
	    [faces,fsomdn_veci,fsomdn_vecj]=facesinsec(fsomdn_veci,fsomdn_vecj,'NE');

	    [mdnbar_vecj,mdnbar_veci]=secingrid(MODEL_sections(13).veci(end),MODEL_sections(13).vecj(end),MODEL_sections(4).veci(1),MODEL_sections(4).vecj(1));
	    [faces,mdnbar_veci,mdnbar_vecj]=facesinsec(mdnbar_veci,mdnbar_vecj,'NW');

	    nordic_boundary_south_i=[MODEL_sections(9).veci,dsoifo_veci(2:end-1),MODEL_sections(10).veci,MODEL_sections(11).veci,fsomdn_veci(2:end-1),MODEL_sections(13).veci,mdnbar_veci(2:end-1),MODEL_sections(4).veci];
	    nordic_boundary_south_j=[MODEL_sections(9).vecj,dsoifo_vecj(2:end-1),MODEL_sections(10).vecj,MODEL_sections(11).vecj,fsomdn_vecj(2:end-1),MODEL_sections(13).vecj,mdnbar_vecj(2:end-1),MODEL_sections(4).vecj];

	case 'RCHB'
	    [hud42n_vecj,hud42n_veci]=secingrid(MODEL_sections(7).veci(1),MODEL_sections(7).vecj(1),MODEL_sections(1).veci(1),MODEL_sections(1).vecj(1));
	    [faces,hud42n_veci,hud42n_vecj]=facesinsec(hud42n_veci,hud42n_vecj,'NE');
	    [s42nfso_vecj,s42nfso_veci]=secingrid(MODEL_sections(1).veci(end),MODEL_sections(1).vecj(end),82,37);
	    subpolar_boundary_south_i=[hud42n_veci,MODEL_sections(1).veci(2:end-1),s42nfso_veci];
	    subpolar_boundary_south_j=[hud42n_vecj,MODEL_sections(1).vecj(2:end-1),s42nfso_vecj];

	    [hudbaf_vecj,hudbaf_veci]=secingrid(MODEL_sections(7).veci(end),MODEL_sections(7).vecj(end),MODEL_sections(8).veci(1),MODEL_sections(8).vecj(1));
	    [bafdso_vecj,bafdso_veci]=secingrid(MODEL_sections(8).veci(end),MODEL_sections(8).vecj(end),MODEL_sections(9).veci(1),MODEL_sections(9).vecj(1));
	    [dsoifo_vecj,dsoifo_veci]=secingrid(MODEL_sections(9).veci(end),MODEL_sections(9).vecj(end),MODEL_sections(10).veci(1),MODEL_sections(10).vecj(1));
	    subpolar_boundary_north_i=[hudbaf_veci(1:end-1),MODEL_sections(8).veci,bafdso_veci(2:end-1),MODEL_sections(9).veci,dsoifo_veci(2:end-1),MODEL_sections(10).veci,MODEL_sections(11).veci];
	    subpolar_boundary_north_j=[hudbaf_vecj(1:end-1),MODEL_sections(8).vecj,bafdso_vecj(2:end-1),MODEL_sections(9).vecj,dsoifo_vecj(2:end-1),MODEL_sections(10).vecj,MODEL_sections(11).vecj];

	    [dsonon_vecj,dsonon_veci]=secingrid(MODEL_sections(9).veci(1),MODEL_sections(9).vecj(1),MODEL_sections(5).veci(1),MODEL_sections(5).vecj(1));
	    nordic_boundary_north_i=[dsonon_veci(1:end-1),MODEL_sections(5).veci(1:end-1),MODEL_sections(4).veci(1:end)];
	    nordic_boundary_north_j=[dsonon_vecj(1:end-1),MODEL_sections(5).vecj(1:end-1),MODEL_sections(4).vecj(1:end)];
[fsomdn_vecj,fsomdn_veci]=secingrid(MODEL_sections(11).veci(end),MODEL_sections(11).vecj(end),MODEL_sections(13).veci(1),MODEL_sections(13).vecj(1));
	    [faces,fsomdn_veci,fsomdn_vecj]=facesinsec(fsomdn_veci,fsomdn_vecj,'NE');

	    [mdnbar_vecj,mdnbar_veci]=secingrid(MODEL_sections(13).veci(end),MODEL_sections(13).vecj(end),MODEL_sections(4).veci(end),MODEL_sections(4).vecj(end));

	    nordic_boundary_south_i=[MODEL_sections(9).veci,dsoifo_veci(2:end-1),MODEL_sections(10).veci,MODEL_sections(11).veci,fsomdn_veci(2:end-1),MODEL_sections(13).veci,mdnbar_veci(2:end-1),MODEL_sections(4).veci];
	    nordic_boundary_south_j=[MODEL_sections(9).vecj,dsoifo_vecj(2:end-1),MODEL_sections(10).vecj,MODEL_sections(11).vecj,fsomdn_vecj(2:end-1),MODEL_sections(13).vecj,mdnbar_vecj(2:end-1),MODEL_sections(4).vecj];

    	otherwise
                error('JD PAGO error: sections_MODEL undefined for this model');
    end

    if ~monotonous(subpolar_boundary_south_i) 
        error(' JD PAGO error : subpolar-boundary-south is not monotonous')
    end

    if  ~monotonous(subpolar_boundary_north_i)
        error('JD PAGO error : subpolar-boundary-north is not monotonous')
    end

    if ~monotonous(nordic_boundary_south_i) 
        error('JD PAGO error : nordic-boundary-south is not monotonous')
    end

    if  ~monotonous(nordic_boundary_north_i)
        error('JD PAGO error : nordic-boundary-north is not monotonous')
    end
%

    subpolar=zeros(size(MODEL_grid.mask));
    subpolar_vol=zeros(nz,nj,ni);

    for ii=subpolar_boundary_south_i(1):subpolar_boundary_south_i(end)
        indis=find(subpolar_boundary_south_i==ii);
        js=min(subpolar_boundary_south_j(indis))+1;
        indin=find(subpolar_boundary_north_i==ii);
        jn=min(subpolar_boundary_north_j(indin));
    
        for jj=js:jn
            if MODEL_grid.mask(jj,ii)>0
                subpolar(jj,ii)=1;
                subpolar_vol(:,jj,ii)=volume(:,jj,ii);
            end
        end
    end

    nordic=zeros(size(MODEL_grid.mask));
    nordic_vol=zeros(nz,nj,ni);

    for ii=nordic_boundary_south_i(1):nordic_boundary_south_i(end)
        indis=find(nordic_boundary_south_i==ii);
        js=min(nordic_boundary_south_j(indis))+1;
        indin=find(nordic_boundary_north_i==ii);
        jn=min(nordic_boundary_north_j(indin));
    
        for jj=js:jn
            if MODEL_grid.mask(jj,ii)>0 && subpolar(jj,ii)==0
                nordic(jj,ii)=1;
                nordic_vol(:,jj,ii)=volume(:,jj,ii);
            end
        end
    end

    MODEL_area(1).name='subpol';
    MODEL_area(1).mask=subpolar;
    [j,i]=find(subpolar==1);
    MODEL_area(1).indi=i;
    MODEL_area(1).indj=j;
    MODEL_area(1).surface=diag(surface(MODEL_area(1).indj,MODEL_area(1).indi));
    MODEL_area(2).name='nordic';
    MODEL_area(2).mask=nordic;
    [j,i]=find(nordic==1);
    MODEL_area(2).indi=i;
    MODEL_area(2).indj=j;
    MODEL_area(2).surface=diag(surface(MODEL_area(2).indj,MODEL_area(2).indi));
    for z=1:nz
	MODEL_area(1).volume(z,:)=diag(squeeze(subpolar_vol(z,MODEL_area(1).indj,MODEL_area(1).indi)));
	MODEL_area(2).volume(z,:)=diag(squeeze(nordic_vol(z,MODEL_area(2).indj,MODEL_area(2).indi)));
    end

    for area=1:length(MODEL_area)
        MODEL_area(area).temperature=NaN*ones(1,nz,length(MODEL_area(area).indi));
        MODEL_area(area).salinity=NaN*ones(1,nz,length(MODEL_area(area).indi));
    end


    figure(12)
    for i=1:ni
        for j=1:nj
            if subpolar(j,i)==1
                plot(i,j,'rs')
            end
            if nordic(j,i)==1
                plot(i,j,'g*')
            end
        end
    end

    title('sections in grid and areas for volumetric census')
end


%% save information in matlab file

MODEL_time=NaN;

if input('save data? (0 or 1) ')
   if nargin>0
	structfile=varargin{1};
   else
       structfile=input('enter filename (including full path) to be used (.mat file): ','s'); 
   end
   if exist('MODEL_area','var') 
       eval(['save ' structfile ' MODEL_grid MODEL_sections MODEL_area MODEL_time'])
   else
       eval(['save ' structfile ' MODEL_grid MODEL_sections MODEL_time'])
   end
   disp(['save ' structfile])
end

    
